function [ videos, info ] = ap_VOGetVideos ( class, params )
% Return the directories and information of the videos avaialable for a certain
% category "class". If "params" is provided, then the routine filters out those
% directories that do not comply with the parameters specified in "params"

if nargin < 2 || isempty(params), params = []; end
bootstrap = false;

if isempty(params)
	minlen = -1; 
	onlyGT = 0;
else 
	minlen = params.videos.minlen;
	onlyGT = params.videos.GT;
end

datadir = [ap_VOCategories(class) 'data/']; % Get the right directory

if isempty(params) || ~isfield(params.videos,'maskfile')
  maskfile = [ap_VOCategories(class) 'sets/all.txt'];
else
  maskfile = [ap_VOCategories(class) 'sets/' params.videos.maskfile];
end

if ~isempty(maskfile)
  % -------------------------------------------
  % Read which shots we should use from a file
  % -------------------------------------------
  fid = fopen(maskfile,'r');
  c = 0;
  while ~feof(fid)    
    a = fgetl(fid);
    if isempty(a) || a(1) == '#' || ~isempty(strfind(a,'shit')), continue; end % Skip comments
    c=c+1;
    data = strsplit(' ',a);

    video{c} = [datadir '//' data{1}];  
  end
  fclose(fid);
else
  video = ap_Dir([datadir '/' maskVideo], true);
  video = sort(video);
  videos = []; info = [];
end

c=0; s_ = [];
v=0; v_ = [];
n_ = 0; % Number of images
videos = []; 

% -------------------------------------------
% Read the shots
% -------------------------------------------
for i = video

  v=v+1;
  s=0;

  shots = ap_Dir([i{1} '/shots/*'], true);
  shots = sort(shots);

  % For each ad, loop over its shots
  for j = shots

    s=s+1; % Shot counter
    l = length(ap_Dir([j{1} '/*.jpg'])); % Get the images
    gt = ap_Dir([j{1} '/*_sticks.mat']); % Get the annotations

    if l < minlen ... 
      || (onlyGT && isempty(gt)) ...
      || (~isempty(params) && ~exist([j{1} '/' params.trackname '.mat'],'file') && ~bootstrap),
      continue; 
    end

    c=c+1;
    videos{c} = j{1};
    info(c).v = v;
    info(c).s = s;
    info(c).n = l;

    if ~isempty(gt)
      for k = gt
        [~,file] = fileparts(k{1});
        frame = str2num(file(isstrprop(file,'digit')));
        load(k{1},'coor');
        coor{1} = [min(coor{1}([1 3])) ; min(coor{1}([2 4])) ; max(coor{1}([1 3])) ; max(coor{1}([2 4]))];
        info(c).gt{frame} = cellmat(coor{1}); % TODO: watch out we use only 1 annotation!
      end
    end

  end
end


end

