function demo
% This function demonstrate how to access the Youtube-Objects dataset for
% two common operations:
%
% 1) Retrieve and visualize candidate tubes and the automatically selected
% tube
%
% 2) Retrieve shots that contain an annotation and visualize it


dataset = [];
class = 'aeroplane'; % We demonstrate on the aeroplane class


class_dir = ap_VOCategories(class);
tubes_selection_file = [class_dir '/selected_tubes_VID.list'];

% --------------------------------------------------------------------
% --------------------------------------------------------------------
% 1) Retrieve and visualize candidate tubes and the automatically selected
% tube from a shot
% --------------------------------------------------------------------
% --------------------------------------------------------------------
params = initVideoObjectOptions();

% The following call returns the tubes automatically selected by our
% approach
[shots, tubes] = ap_VOGetTubes(class, params, tubes_selection_file);

% Draw the automatically selected tube from one of the shots
draw_shot_number = 62;

selected_tube = tubes{draw_shot_number};

% Load the list of images for this shot and the whole set of candidate tubes
load ([shots{draw_shot_number} '/dataset.mat'],'dataset');
load ([shots{draw_shot_number} '/' params.trackname], 'T');

figure;
for i = 1 : length(dataset) - 1
  
  % Show the video frame
  imshow([shots{draw_shot_number} '/' dataset(i).file]);
  
  % Loop on all candidate tubes
  for j = 1 : size(T,1)
    if isempty(T{j,i})
      continue; 
    end
    
    % Overlat all candidate tubes
    x1 = T{j,i}(1);
    y1 = T{j,i}(2);
    x2 = T{j,i}(3);
    y2 = T{j,i}(4);
    
    line([x1 x1 x2 x2 x1]',[y1 y2 y2 y1 y1]','color','yellow','linewidth',2);
  end
  
  % Overlay the automatically selected tube (if present at this frame)
  if size(selected_tube,2) >= i && ~isempty(selected_tube{1,i})
    x1 = selected_tube{1,i}(1);
    y1 = selected_tube{1,i}(2);
    x2 = selected_tube{1,i}(3);
    y2 = selected_tube{1,i}(4);
    
    line([x1 x1 x2 x2 x1]',[y1 y2 y2 y1 y1]','color','blue','linewidth',2);
  end
  drawnow;
 
end
disp('Press any key to continue');
pause;

% --------------------------------------------------------------------
% --------------------------------------------------------------------
% 2) Retrieve shots that contain an annotation and visualize it
% --------------------------------------------------------------------
% --------------------------------------------------------------------

only_gt = 1; % Selects only annotated shots
min_frames = 20; % Selects shots longer than 20 frames

% Initialize shot selection parameters "params" based on simple criteria
params = initVideoObjectOptions(min_frames, only_gt);

% The following call selects a subset of shots matching the criteria
% defined in "params"
[shots, info] = ap_VOGetVideos(class,params);

% Choose the shot number we are going to draw
draw_shot_number = 2;
frame_number = find(1-cellfun(@isempty,info(draw_shot_number).gt));
frame_number = frame_number(1);

load ([shots{draw_shot_number} '/dataset.mat'],'dataset');
imshow ([shots{draw_shot_number} '/' dataset(frame_number).file]);

% Overlay the annotation
x1 = info(draw_shot_number).gt{frame_number}(1);
y1 = info(draw_shot_number).gt{frame_number}(2);
x2 = info(draw_shot_number).gt{frame_number}(3);
y2 = info(draw_shot_number).gt{frame_number}(4);

line([x1 x1 x2 x2 x1]',[y1 y2 y2 y1 y1]','color','green','linewidth',2);

end

